package org.relaxng.datatype;

/**
 * signals datatype related exceptions.
 * 
 * @author <a href="mailto:kohsuke.kawaguchi@eng.sun.com">Kohsuke KAWAGUCHI</a>
 */
public class DataTypeException extends Exception {
	
	public DataTypeException( DataType type, String content, int index, String msg ) {
		super(msg);
		this.type = type;
		this.content = content;
		this.index = index;
	}
	public DataTypeException( String msg ) {
		this(null,null,UNKNOWN,msg);
	}

	protected String content;

	/** gets the lexcial representation of data that caused an error */
	public String getContent() {
		return content;
	}
	
	protected DataType type;
	
	/** gets the datatype object that generates this error. */
	public DataType getDataType() {
		return type;
	}
	
	protected int index;
	
	public static int UNKNOWN = -1;

	/**
	 * gets the index of the content where the error occured.
	 * UNKNOWN can be returned to indicate that no index information is available.
	 */
	public int getIndex() {
		return index;
	}
}
