package org.relaxng.datatype;

/**
 * one datatype library
 * 
 * @author <a href="mailto:kohsuke.kawaguchi@eng.sun.com">Kohsuke KAWAGUCHI</a>
 */
public interface DataTypeLibrary {
	
	/**
	 * creates a new type builder instance.
	 * 
	 * The callee should throw a DataTypeException in case of an error.
	 * If an error is because of the undefined baseTypeLocalName, then
	 * it can return null instead of throwing an exception.
	 * 
	 * @param baseTypeLocalName
	 *		local name of the base type.
	 * 
	 * @return null
	 *		The callee can return null if baseTypeLocalName is an undefined name.
	 */
	DataTypeBuilder createDataTypeBuilder( String baseTypeLocalName )
		throws DataTypeException;
	
	/**
	 * gets a pre-defined type.
	 * 
	 * This is just a short-cut of createTypeIncubator(name).derive();
	 * 
	 * The callee should throw a DataTypeException in case of an error.
	 * If the error is because of the undefined baseTypeLocalName, then
	 * it can return null instead of throwing an exception.
	 * 
	 * @return null
	 *		The callee can return null if localTypeName is an undefined name.
	 */
	DataType getType( String localTypeName ) throws DataTypeException;
}
