package org.relaxng.datatype;

/**
 * Datatype streaming validator.
 * 
 * The streaming validator is an optional feature that is useful for
 * certain datatypes. It allows the caller to incrementally provide
 * the literal.
 * 
 * @author <a href="mailto:kohsuke.kawaguchi@eng.sun.com">Kohsuke KAWAGUCHI</a>
 */
public interface DataTypeStreamingValidator {
	
	/**
	 * purges the accumulated literal, and start all over again.
	 * 
	 * <p>
	 * This method can be used to reduce the number of the creation of
	 * this datatype.
	 */
	void reset();
	
	/**
	 * let a streaming validator process additional literal fragment.
	 * 
	 * <p>
	 * The application can call this method several times, then call
	 * the isValid method to check the validity.
	 * 
	 * @return
	 *		the return value of this method is the return value
	 *		of the isValid method after processing new literal fragment.
	 */
	boolean characters( char[] buf, int start, int len );
	
	/**
	 * gets if the accumulated literal is valid with respect to
	 * the underlying datatype.
	 * 
	 * @return
	 *		true if it is valid. False if otherwise.
	 */
	boolean isValid();
}
