package org.relaxng.datatype.helpers;

import org.relaxng.datatype.*;

/**
 * Dummy implementation of {@link DataTypeStreamingValidator}.
 * 
 * This implementation can be used as a quick hack when the performance
 * of streaming validation is not important.
 * 
 * <p>
 * Typical usage would be:
 * <PRE><XMP>
 * class MyDataType implements DataType {
 *     ....
 *     public DataTypeStreamingValidator createStreamingValidator( ValidationContext context ) {
 *         return new StreamingValidatorImpl(this,context);
 *     }
 *     ....
 * }
 * </XMP></PRE>
 * 
 * @author <a href="mailto:kohsuke.kawaguchi@eng.sun.com">Kohsuke KAWAGUCHI</a>
 */
public final class StreamingValidatorImpl implements DataTypeStreamingValidator {
	
	/** this buffer accumulates characters. */
	private StringBuffer buffer = new StringBuffer();
	
	/** DataType obejct that creates this streaming validator. */
	private final DataType baseType;
	
	/** the current context. */
	private final ValidationContext context;
	
	public void reset() {
		// flush the buffer.
		buffer = new StringBuffer();
	}
	
	public boolean characters( char[] buf, int start, int len ) {
		// append characters to the current buffer.
		buffer.append(buf,start,len);
		return isValid();
	}
	
	public boolean isValid() {
		return baseType.allows(buffer.toString(),context);
	}
	
	public StreamingValidatorImpl( DataType baseType, ValidationContext context ) {
		this.baseType = baseType;
		this.context = context;
	}
}
